<?php 


    function RoundWireCalc( $s1, $s2, $d ) {
		
		$L = RectLoopIndRoundWire( $s1, $s2, $d / 1000.0 );

		return $L;
    }
	
	/* RectLoopIndRoundWire(a, b, d) - returns the inductance of a single turn rectangular loop of round wire
	 * a: rectangle side length [m]
	 * b: rectangle other side length [m]
	 * d: wire diameter [m]
	 */
	function RectLoopIndRoundWire( $a, $b, $d ) {
	  /* the formula was converted to metric units */
	
	  $g = sqrt( $a * $a + $b * $b );
	  $l = 0.4 * (($a + $b) * log(4.0 * $a * $b / $d) - $a * log($a + $g) - $b * log($b + $g)) + 0.4 * (2.0 * $g + $d - 2.0 * ($a + $b));
	
	  return $l;
	}

	
	/* RegLoopInd(p, d, idx) - returns the inductance of a single turn loop of regular shape
	 * p: loop perimeter [m]
	 * d: loop wire diameter [m]
	 * idx: loop type index (see below)
	 */
	function RegLoopInd( $p, $d, $idx ) {
	
	  switch ($idx) {
		case 0: 
		  $theta = 2.451; /* circle */
		break;
		case 1:  
		  $theta = 2.561; /* regular octagon */
		break;
		case 2:
		  $theta = 2.636; /* regular hexagon */
		break;
		case 3:
		  $theta = 2.712; /* regular pentagon */
		break;
		case 4:
		  $theta = 2.853; /* square */
		break;
		case 5:
		  $theta = 3.197; /* equilateral triangle */
		break;
		case 6:
		  $theta = 3.332; /* isosceles right-angled triangle */
		break;
		default:
		  $theta = 100; 	 /* error */
	   } 
		   
	   $l = 2.0e-07 * $p * (log(4.0 * $p / $d) - $theta) *  1e06;  // Return uH
	
	   return $l;
	}

	
	
	if ( isset($_GET["type"]) ) {
	
		switch ($_GET["type"]) {
			case "rectangular":
				$s1 = $_GET["s1"] ;
				$s2 = $_GET["s2"] ;
				$d = $_GET["d"] ;
		
				$L = Round( RoundWireCalc( $s1, $s2, $d ), 1);
				$type = "rectangular";
				break;
				
			case "shaped":
				$p = $_GET["p"];
				$d = $_GET["d"] / 1000.0;
				$shape_idx = $_GET["coil_shape"];
				
				$L = Round(  RegLoopInd( $p, $d, $shape_idx ), 1);
				$type = "shaped";
				break;
		}		
	}
	else {
		$type = "";
		$shape_idx = "";
	}

?>


<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="en">

<!--  Version: Multiflex-3 Update-1 / Layout-1             -->
<!--  Date:    November 27, 2006                           -->
<!--  Author:  G. Wolfgang                                 -->
<!--  License: Fully open source without restrictions.     -->
<!--           Please keep footer credits with a link to   -->
<!--           G. Wolfgang (www.1-2-3-4.info). Thank you!  -->

<head>

  <?php include '../includes/meta.html'; ?>
  <link rel="stylesheet" type="text/css" media="screen,projection,print" href="/css/layout1_setup.css" />
  <link rel="stylesheet" type="text/css" media="screen,projection,print" href="/css/layout1_text.css" />
  <link rel="icon" type="image/x-icon" href="/img/favicon.ico" />
  <title>One-Turn Inductor Calculations</title>
</head>

<!-- Global IE fix to avoid layout crash when single word size wider than column width -->
<!--[if IE]><style type="text/css"> body {word-wrap: break-word;}</style><![endif]-->

<body>
  <!-- Main Page Container -->
  <div class="page-container">

   <!-- For alternative headers START PASTE here -->

    <!-- A. HEADER -->      
    <div class="header">
      
      <!-- A.1 HEADER TOP -->
	  <?php include '../includes/HeaderTop.incl.html'; ?>
      
      <!-- A.2 HEADER BOTTOM -->
	  <?php include '../includes/HeaderBottom.incl.html'; ?>

      <!-- A.3 HEADER BREADCRUMBS -->

      <!-- Breadcrumbs -->
      <div class="header-breadcrumbs">
        <ul>
          <li><a href="/index.php">Home</a></li>
          <li>One-Turn Inductor Calculations</li>
        </ul>

        <!-- Search form -->                  
		<?php include '../includes/SearchForm.incl.php'; ?>
      </div>
    </div>
   <!-- For alternative headers END PASTE here -->

    <!-- B. MAIN -->
    <div class="main">
  
      <!-- B.1 MAIN CONTENT -->
      <div class="main-content">
        
        <!-- Pagetitle -->
        <h1 class="pagetitle">One Turn Inductor Calculations</h1>

		<h2>Shaped One-Turn Inductance</h2>

			<p>
				This is for a various shaped, one-turn loops.
			</p>
			
			<form name="calcInductor" action="one-turn-inductor.php" method="get">
			<input type="hidden" name="type" value="shaped" />			
			
			<table>
			<tr><th>Loop perimeter</th><td>l = <input type="text" name="p" size="10" maxlength="10" value="31.4" /> m</td></tr>
			<tr><th>Wire diameter</th><td>d = <input type="text" name="d" size="10" maxlength="10" value="5" /> mm</td></tr>
			<tr><th>Loop shape</th><td><select name="coil_shape" size="1" >
			<option value="0" <?php if ( $shape_idx == 0 ) { echo 'selected="selected"'; } ?> >Circle</option>
			<option value="1" <?php if ( $shape_idx == 1 ) { echo 'selected="selected"'; } ?> >Regular octagon</option>
			<option value="2" <?php if ( $shape_idx == 2 ) { echo 'selected="selected"'; } ?> >Regular hexagon</option>
			
			<option value="3" <?php if ( $shape_idx == 3 ) { echo 'selected="selected"'; } ?> >Regular pentagon</option>
			<option value="4" <?php if ( $shape_idx == 4 ) { echo 'selected="selected"'; } ?> >Square</option>
			<option value="5" <?php if ( $shape_idx == 5 ) { echo 'selected="selected"'; } ?> >Equilateral triangle</option>
			<option value="6" <?php if ( $shape_idx == 6 ) { echo 'selected="selected"'; } ?> >Isosceles right-angled triangle</option>
			</select>
			</td></tr>
			</table>
			<input type="submit" value="Calculate"/>
			
			<h2>Calculated Inductance for a One-Turn Shaped Inductance</h2>
			
			<table>
			<tr><th>Inductance</th><td>L = <?php if ( $type == "shaped" ) {  echo $L; } ?> &#181;H </td></tr>
			</table>

			</form>
			

		<h2>Rectangular Coil Inductance</h2>

			<p>
				This is for a one-turn rectangular loop.
			</p>

			<form name="calcInductor" action="one-turn-inductor.php" method="get">
			<input type="hidden" name="type" value="rectangular" />
			
			<table>
			<tr><th>Rectangle side</th><td>s1 = <input type="text" name="s1" size="10" maxlength="10" value=".3" /> m</td></tr>
			<tr><th>Other Rectangle side</th><td>s2 = <input type="text" name="s2" size="10" maxlength="10" value=".3" /> m</td></tr>
			<tr><th>Wire diameter</th><td>d = <input type="text" name="d" size="10" maxlength="10" value="10" /> mm</td></tr>
			</table>
			<input type="submit" value="Calculate" />
			

			<h2>Calculated Inductance for a One-Turn Rectangular Inductance</h2>
			
			<table>
			<tr><th>Inductance</th><td>L = <?php if ( $type == "rectangular" ) { echo $L; } ?> &#181;H </td></tr>
			</table>
			</form>

		<p>For more technical data, see: F.E. Terman, "<strong>Radio Engineers' Handbook</strong>," London, McGraw-Hill, 1st ed., Sep. 1950.</p>
 

      </div>
    </div>
      
    <!-- C. FOOTER AREA -->      
	<?php include '../includes/Footer.incl.html'; ?>
	
  </div> 
  
</body>
</html>